@@ -22,6 +22,125 @@ NULL
 
 # Module definition -------------------------------------------------------
 
+## UI part ----------------------------------------------------------------
+
+#' @rdname sm_cat_internal
+#'
+#' @importFrom plotly plotlyOutput
+#'
+sm_cat_ui <- function(id, imports = NULL, ...) {
+  ns <- NS(id)
+
+  tagList(
+    h3("Computerized Adaptive Tests"),
+    p(
+      "This module provides a demonstration of computerized adaptive testing (CAT) using the ",
+      tags$code("{mirtCAT}"),
+      " package. In the first part of the module, a response pattern for the
+      complete test is generated based on the estimated IRT model for a respondent with a specified true ability level \\(\\theta\\).",
+      "Then, a post-hoc CAT simulation is performed on the generated response pattern as if the respondent were taking a CAT.",
+    ),
+    fluidRow(
+      column(
+        3,
+        selectInput(
+          ns("irt_model"),
+          "IRT model to use",
+          choices = c(
+            "Module's example 2PL" = "example"
+          )
+        )
+      ),
+      column(
+        3,
+        sliderInput(
+          ns("true_theta"),
+          # math mode is delimited with \( and \)
+          # in R you have to escape \ with another \, hence the \\
+          # SIAtools::preview_mod() ensures that the math is rendered using KaTeX JS library
+          # see ?SIAtools::sia_head_tag documentation for details
+          "Respondent's true ability (\\(\\theta\\))",
+          value = 1,
+          min = -4,
+          max = 4,
+          step = .1
+        )
+      )
+    ),
+    h4("Generated response pattern"),
+    fluidRow(
+      column(12, uiOutput(ns("basic_stats")))
+    ),
+    fluidRow(
+      column(
+        12,
+        tableOutput(ns("resp_patt")),
+        style = "margin: 15px 0 20px 0;"
+      ),
+    ),
+    h4("CAT post-hoc simulation"),
+    p(
+      "At each step of the CAT (left slider),
+      the item with the highest information for the current ability estimate (left part of the figure)
+      is presented to the respondent. Based on the respondent's answer (correct/incorrect),
+      a new ability estimate is computed (right part of the figure).
+      This process is repeated iteratively until a stopping criterion\u2014defined here by the standard error (SE) of the ability estimate (second slider)\u2014is
+      met. For tests with a large number of items, you can choose to display only the items that were eventually administered (checkbox on the right)."
+    ),
+    fluidRow(
+      column(
+        3,
+        # use less efficient way to obtain nice ticks in the slider
+        # normal way would be to use `sliderInput()` here and
+        # `updateSliderInput()` in the server part
+        uiOutput(ns("item_pos_ui"))
+      ),
+      column(
+        3,
+        sliderInput(
+          ns("min_se"),
+          "Min. SE",
+          value = .35,
+          min = 0,
+          max = 1.5,
+          step = .01
+        )
+      ),
+      column(
+        3,
+        checkboxInput(
+          ns("only_ans"),
+          "Show IICs for only administered items",
+          value = FALSE
+        )
+      )
+    ),
+    plotlyOutput(ns("merged"), height = "550px"),
+
+    # sample R code -----------------------------------------------------------
+
+    h4("Selected R code"),
+    pre(
+      includeText(system.file("sc/cat.R", package = "SIAmodules")),
+      class = "mb-4 language-r"
+    ),
+
+    # references --------------------------------------------------------
+
+    h4("References"),
+    p(
+      "Martinkova, P., & Hladka, A. (2023).",
+      tags$i("Computational Aspects of Psychometric Methods: With R."),
+      "Chapman and Hall/CRC.",
+      tags$a(
+        "doi:10.1201/9781003054313",
+        href = "https://doi.org/10.1201/9781003054313",
+        target = "_blank"
+      )
+    )
+  )
+}
+
 ## Server part ------------------------------------------------------------
 
 #' `sm_cat` module (internal documentation)
@@ -52,7 +171,7 @@ NULL
 #' @importFrom forcats fct_inorder
 #' @importFrom dplyr mutate filter pull
 #' @importFrom tibble tibble
-#' @importFrom purrr set_names map_dfc map_int
+#' @importFrom purrr set_names map_dfc map_int map2_chr
 #' @importFrom tidyr pivot_longer
 #' @importFrom mirt extract.item extract.mirt iteminfo
 #' @importFrom stats qnorm
@@ -69,21 +188,14 @@ sm_cat_server <- function(id, imports = NULL, ...) {
       # check if the module is run inside SIA app,
       # SIA >= 1.5.0 provides more detailed info that we cannot check on SIA 1.5.0
       if (packageVersion("ShinyItemAnalysis") > "1.5.0") {
-        runs_from_sia <- !is.null(imports) && !is.null(attr(imports, "imported_by_sia")) && attr(imports, "imported_by_sia")
+        runs_from_sia <- !is.null(imports) &&
+          !is.null(attr(imports, "imported_by_sia")) &&
+          attr(imports, "imported_by_sia")
       } else {
         runs_from_sia <- !is.null(imports)
       }
 
-
       if (runs_from_sia) {
-        # list these specified IRT models that comes from the app
-        irt_models <- c(
-          "Module's example 2PL" = "example",
-          "SIA-fitted IRT for binary data" = "sia_binary",
-          "SIA-fitted NRM" = "sia_nrm"
-        )
-
-        # and pass it as the choices to be displayed in the UI
         updateSelectInput(inputId = "irt_model", choices = irt_models)
       }
     })
@@ -91,28 +203,51 @@ sm_cat_server <- function(id, imports = NULL, ...) {
     # IRT model object
     mod <- reactive({
       # return the appropriate IRT model based on the `input$irt_model`
-      switch(input$irt_model,
+      switch(
+        input$irt_model,
         example = example_2pl_mod,
         sia_binary = imports$IRT_binary_model(),
         # object for NRM option consist of fitted model and some additional information
         # that we have no use for in this module
         sia_nrm = {
           fit <- imports$IRT_bock_fit_and_orig_levels()[["fit"]]
-          attr(fit, "orig_levels") <- imports$IRT_bock_fit_and_orig_levels()[["orig_levels"]]
+          attr(fit, "orig_levels") <- imports$IRT_bock_fit_and_orig_levels()[[
+            "orig_levels"
+          ]]
           fit
         },
       )
     })
 
+    n_items <- reactive({
+      req(mod())
+      extract.mirt(mod(), "nitems")
+    })
+
+    model_type <- reactive({
+      req(mod())
+      types <- extract.mirt(mod(), "itemtype")
+      type <- unique(types)
+
+      validate(
+        need(length(type) == 1L, "All items must be of the same type."),
+        need(
+          type %in% c("Rasch", "1PL", "2PL", "3PL", "4PL", "nominal"),
+          "Only Rasch, 1PL, 2PL, 3PL, 4PL, and NRM models are supported."
+        )
+      )
+
+      type
+    })
 
     item_infos <- reactive({
       req(mod())
 
-      items <- seq_len(extract.mirt(mod(), "nitems")) %>% set_names()
+      items <- seq_len(n_items()) |> set_names()
 
-      items %>%
-        map_dfc(~ extract.item(mod(), .x) %>% iteminfo(info_thetas)) %>%
-        mutate(theta = info_thetas) %>%
+      items |>
+        map_dfc(~ extract.item(mod(), .x) |> iteminfo(info_thetas)) |>
+        mutate(theta = info_thetas) |>
         pivot_longer(-.data$theta, values_to = "info", names_to = "item")
 
       # note that `info_thetas` is defined outside the server function at the very bottom of this file
@@ -120,20 +255,91 @@ sm_cat_server <- function(id, imports = NULL, ...) {
       # (all .R/.rda files there are sourced and the results available to use in your package)
     })
 
+    resp_patt <- reactive({
+      # based on given theta, generate plausible response pattern
+      generate_pattern(mod(), input$true_theta)
+    })
+
+    key_and_levels <- reactive({
+      # for binary models, the key is always 1 for correct response
+      key <- rep(1L, n_items())
+      orig_levels <- NULL
+
+      if (model_type() == "nominal") {
+        orig_levels <- attr(mod(), "orig_levels")
+        key <- orig_levels |> map_int(~ which(attr(.x, "key")))
+      }
+
+      list(key = key, orig_levels = orig_levels)
+    })
+
+    resp_patt_scored <- reactive({
+      pat <- resp_patt()
+      pat <- pat[1L, , drop = TRUE]
+
+      # name the items I1, I2, ...
+      names(pat) <- paste0("I", seq_along(pat))
+
+      is_correct <- pat == key_and_levels()$key
+
+      if (!is.null(key_and_levels()$orig_levels)) {
+        # for NRM, replace numeric responses with original factor levels
+        pat <- map2_chr(pat, key_and_levels()$orig_levels, \(x, y) y[x])
+      }
+
+      list(pat = pat, is_correct = is_correct)
+    })
+
+    output$resp_patt <- renderTable(
+      {
+        pat <- resp_patt_scored()$pat
+        is_correct <- resp_patt_scored()$is_correct
+
+        pat[is_correct] <- paste0("<b>", pat[is_correct], "</b>")
+
+        pat |> t() |> as.data.frame()
+      },
+      sanitize.text.function = identity # prevent HTML tags escaping
+    )
+
+    # basic stats
+    output$basic_stats <- renderUI({
+      n_items <- n_items()
+      n_correct <- resp_patt_scored()$is_correct |> sum()
+      perc_correct <- round((n_correct / n_items) * 100, 2L)
+
+      HTML(
+        paste0(
+          "Based on the ",
+          names(irt_models)[irt_models == input$irt_model],
+          " model, ",
+          n_items,
+          " responses to ",
+          n_items,
+          " items were generated for a respondent with a true ability of \\(\\theta\\) = ",
+          input$true_theta,
+          ". The full response pattern is presented in the table below, where the correct answers are shown in bold. ",
+          "The total score for the complete test would be ",
+          n_correct,
+          " (",
+          perc_correct,
+          "% correct)."
+        )
+      )
+    })
 
     # create a reactive component that "listens" for any change of UI inputs or anything reactive
     sim_res_raw <- reactive({
-      # based on given theta, generate plausible response pattern
-      pat <- generate_pattern(mod(), input$true_theta)
+      req(mod(), resp_patt())
 
       mirtCAT(
         mo = mod(),
-        local_pattern = pat,
+        local_pattern = resp_patt(),
         start_item = "MI",
         method = "MAP",
         criteria = "MI",
         design = list(min_SEM = input$min_se) # pass the input value
-      ) %>%
+      ) |>
         summary()
     })
 
@@ -148,13 +354,14 @@ sm_cat_server <- function(id, imports = NULL, ...) {
         item = c(0L, sim_res_raw$items_answered),
         theta = sim_res_raw$thetas_history[, 1],
         se = sim_res_raw$thetas_SE_history[, 1],
-      ) %>% mutate(
-        item_pos = seq_along(.data$item) - 1L,
-        item = .data$item %>% as.factor() %>% fct_inorder(),
-        ci = .data$se * qnorm(.975), # for 95% CI
-        lci = .data$theta - .data$ci,
-        uci = .data$theta + .data$ci,
-      )
+      ) |>
+        mutate(
+          item_pos = seq_along(.data$item) - 1L,
+          item = .data$item |> as.factor() |> fct_inorder(),
+          ci = .data$se * qnorm(.975), # for 95% CI
+          lci = .data$theta - .data$ci,
+          uci = .data$theta + .data$ci,
+        )
     })
 
     # render the UI with a fresh sliderInput for current item position, with
@@ -166,14 +373,16 @@ sm_cat_server <- function(id, imports = NULL, ...) {
       sliderInput(
         ns("item_pos"),
         "CAT step",
-        value = 0, min = 0, max = n_administered_items, step = 1,
+        value = 0,
+        min = 0,
+        max = n_administered_items,
+        step = 1,
         animate = animationOptions(
           interval = 2000
         )
       )
     })
 
-
     # make two reactives, one for each plot - there are situations that effectively changes only one of them
     # think of toggling the `input$only_ans` button - neither the plot with estimates
     # nor the underlying data are subject of change, but the filtered data are
@@ -183,11 +392,12 @@ sm_cat_server <- function(id, imports = NULL, ...) {
     estimates_plt <- reactive({
       bkg_data <- sim_res()
 
-      filtered_data <- bkg_data %>%
+      filtered_data <- bkg_data |>
         filter(.data$item_pos <= input$item_pos)
 
-      filtered_data %>%
-        ggplot(aes(.data$item,
+      filtered_data |>
+        ggplot(aes(
+          .data$item,
           group = 1,
           text = glue(
             "<b>Item: {.data$item}</b>
@@ -195,21 +405,57 @@ sm_cat_server <- function(id, imports = NULL, ...) {
             95% CI [{round(.data$lci, 2L)}, {round(.data$uci, 2L)}]"
           )
         )) +
-        geom_segment(aes(y = cur_theta(), yend = cur_theta(), x = 0.85, xend = input$item_pos + 1L), linetype = "dashed", col = "gray50") +
-        geom_hline(aes(yintercept = input$true_theta), linetype = "solid", col = "gray80", alpha = .5, size = 1) +
-        geom_ribbon(aes(y = .data$theta, ymin = .data$lci, ymax = .data$uci), alpha = .15, fill = "gray75", data = bkg_data) +
-        geom_ribbon(aes(y = .data$theta, ymin = .data$lci, ymax = .data$uci), alpha = .25, fill = "gray60") +
-        geom_line(aes(y = .data$theta), data = bkg_data, col = "gray70", alpha = .4) +
-        geom_line(aes(y = .data$theta), col = blue, size = .85, alpha = .4) +
+        geom_segment(
+          aes(
+            y = cur_theta(),
+            yend = cur_theta(),
+            x = 0.85,
+            xend = input$item_pos + 1L
+          ),
+          linetype = "dashed",
+          col = "gray50"
+        ) +
+        geom_hline(
+          aes(yintercept = input$true_theta),
+          linetype = "solid",
+          col = "gray80",
+          alpha = .5,
+          linewidth = 1
+        ) +
+        geom_ribbon(
+          aes(y = .data$theta, ymin = .data$lci, ymax = .data$uci),
+          alpha = .15,
+          fill = "gray75",
+          data = bkg_data
+        ) +
+        geom_ribbon(
+          aes(y = .data$theta, ymin = .data$lci, ymax = .data$uci),
+          alpha = .25,
+          fill = "gray60"
+        ) +
+        geom_line(
+          aes(y = .data$theta),
+          data = bkg_data,
+          col = "gray70",
+          alpha = .4
+        ) +
+        geom_line(
+          aes(y = .data$theta),
+          col = blue,
+          linewidth = .85,
+          alpha = .4
+        ) +
         geom_point(aes(y = .data$theta), data = bkg_data, col = "gray80") +
         geom_point(aes(y = .data$theta), col = blue, size = 2) +
         scale_x_discrete(expand = expansion(mult = c(.01, .01))) +
-        scale_y_continuous(limits = range(info_thetas), expand = expansion(mult = c(.01, .01))) +
+        scale_y_continuous(
+          limits = range(info_thetas),
+          expand = expansion(mult = c(.01, .01))
+        ) +
         labs(x = "Item", y = "Ability estimate") +
         theme_minimal()
     })
 
-
     # get the ability estimate based on which current item was chosen (IIC of the item with max. info at that theta)
     cur_theta <- reactive({
       sim_res()[["theta"]][input$item_pos + 1L]
@@ -223,7 +469,6 @@ sm_cat_server <- function(id, imports = NULL, ...) {
       c(0L, administered_items())[input$item_pos + 1L]
     })
 
-
     infos_plt <- reactive({
       next_item <- next_item()
 
@@ -233,22 +478,24 @@ sm_cat_server <- function(id, imports = NULL, ...) {
       # this likely wouldn't have been an issue
       req(!is.na(next_item))
 
-      already_admin <- sim_res() %>%
-        filter(.data$item_pos <= input$item_pos) %>%
+      already_admin <- sim_res() |>
+        filter(.data$item_pos <= input$item_pos) |>
         pull(.data$item)
 
       bkg_data <- item_infos()
 
       # filter only administered items
       if (input$only_ans) {
-        bkg_data <- bkg_data %>% filter(.data$item %in% administered_items())
+        bkg_data <- bkg_data |> filter(.data$item %in% administered_items())
       }
 
-      filtered_data <- bkg_data %>%
+      filtered_data <- bkg_data |>
         filter(.data$item == next_item)
 
-      filtered_data %>%
-        ggplot(aes(.data$theta, .data$info,
+      filtered_data |>
+        ggplot(aes(
+          .data$theta,
+          .data$info,
           group = .data$item,
           text = glue(
             "<b>Item: {.data$item}</b>
@@ -256,15 +503,29 @@ sm_cat_server <- function(id, imports = NULL, ...) {
             Theta: {round(.data$theta, 2L)}"
           )
         )) +
-        geom_vline(aes(xintercept = input$true_theta), linetype = "solid", col = "gray80", alpha = .5, size = 1) +
-        geom_line(aes(col = .data$item %in% already_admin), show.legend = FALSE, alpha = .7, data = bkg_data) +
+        geom_vline(
+          aes(xintercept = input$true_theta),
+          linetype = "solid",
+          col = "gray80",
+          alpha = .5,
+          linewidth = 1
+        ) +
+        geom_line(
+          aes(col = .data$item %in% already_admin),
+          show.legend = FALSE,
+          alpha = .7,
+          data = bkg_data
+        ) +
         {
           if (next_item != "end of the test") {
-            geom_line(show.legend = FALSE, col = blue, size = 1)
+            geom_line(show.legend = FALSE, col = blue, linewidth = 1)
           }
         } +
         geom_vline(aes(xintercept = cur_theta()), linetype = "dashed") +
-        scale_x_continuous(limits = range(info_thetas), expand = expansion(mult = c(.01, .01))) +
+        scale_x_continuous(
+          limits = range(info_thetas),
+          expand = expansion(mult = c(.01, .01))
+        ) +
         scale_color_manual(values = c(`TRUE` = "#2C7BB6", `FALSE` = "gray80")) +
         scale_y_reverse() +
         coord_flip() +
@@ -272,23 +533,15 @@ sm_cat_server <- function(id, imports = NULL, ...) {
         theme_minimal()
     })
 
-
     scored_resps <- reactive({
       sr <- sim_res_raw()$scored_responses
       ans_items <- sim_res_raw()$items_answered
+      key <- key_and_levels()$key
 
-      if (input$irt_model == "sia_nrm") {
-        # score items according to the key SIA NRM
-        orig_levels <- attr(mod(), "orig_levels")
-        corr_ans <- orig_levels %>% map_int(~ which(attr(.x, "key")))
+      # get key for administered items in their order
+      key <- key[ans_items]
 
-        # reorder according to the answered items
-        corr_ans <- corr_ans[ans_items]
-      } else {
-        corr_ans <- rep(1L, length(sr))
-      }
-
-      sr <- ifelse(sr == corr_ans, "correct", "incorrect")
+      sr <- ifelse(sr == key, "correct", "incorrect")
       c(sr, "end of the test")
     })
 
@@ -303,36 +556,52 @@ sm_cat_server <- function(id, imports = NULL, ...) {
         Next item response: {next_item_resp()}"
       )
 
-      infos_plt() %>%
-        ggplotly(tooltip = "text") %>%
+      infos_plt() |>
+        ggplotly(tooltip = "text") |>
         plotly::add_annotations(
-          text = text, showarrow = F, xref = "paper", yref = "paper",
-          x = .02, y = 1, align = "left", xanchor = "left", yanchor = "top"
+          text = text,
+          showarrow = F,
+          xref = "paper",
+          yref = "paper",
+          x = .02,
+          y = 1,
+          align = "left",
+          xanchor = "left",
+          yanchor = "top"
         )
     })
 
-
     estimates_plt_plotly <- reactive({
-      estimates_plt() %>% ggplotly(tooltip = "text")
+      estimates_plt() |> ggplotly(tooltip = "text")
     })
 
     merged_plots <- reactive({
       info <- infos_plt_plotly()
 
-      estimates <- estimates_plt_plotly() %>% plotly::layout(yaxis = list(side = "right"))
+      estimates <- estimates_plt_plotly() |>
+        plotly::layout(yaxis = list(side = "right"))
 
       # merge into one output plotly plot
-      plotly::subplot(info, estimates,
-        titleX = TRUE, titleY = TRUE,
+      plotly::subplot(
+        info,
+        estimates,
+        titleX = TRUE,
+        titleY = TRUE,
         margin = 0,
         widths = c(.3, .7)
-      ) %>%
+      ) |>
         plotly::config(displayModeBar = FALSE)
-    }) %>% # cache the value of the reactive - compute only if any of these objects changes
+    }) |> # cache the value of the reactive - compute only if any of these objects changes
       # note that it is not recommended to include large objects as cache key,
       # because the whole key has to be hashed and objects serialized
       # see https://shiny.rstudio.com/articles/caching.html#faq-large-cache-key
-      bindCache(mod(), input$true_theta, input$min_se, input$item_pos, input$only_ans)
+      bindCache(
+        mod(),
+        input$true_theta,
+        input$min_se,
+        input$item_pos,
+        input$only_ans
+      )
 
     output$merged <- renderPlotly({
       # wait for the input to be available, as we construct the UI for the slider
@@ -356,111 +625,9 @@ info_thetas <- seq(-4, 4, length.out = 300L)
 blue <- "#2C7BB6"
 grey <- "#dadada"
 
-
-## UI part ----------------------------------------------------------------
-
-#' @rdname sm_cat_internal
-#'
-#' @importFrom plotly plotlyOutput
-#'
-sm_cat_ui <- function(id, imports = NULL, ...) {
-  ns <- NS(id)
-
-
-  tagList(
-    h3("Computerized Adaptive Tests"),
-    p(
-      "This module provides illustration of computerized adaptive test (CAT) with the ",
-      tags$code("{mirtCAT}"), " package.",
-      "In the first step of the CAT, the respondent's estimated ability is preset at 0.
-      In each step of the CAT (right slider),
-      the item with the highest information for the estimated ability (left part of the figure)
-      is presented to the respondent, and, based upon their answer (correct/incorrect),
-      a new ability estimate is computed (right part of the figure).
-      This is repeated in an iterative cycle, until a stopping criterion
-      (defined by the standard error of the ability estimate, middle slider) is met."
-    ),
-    fluidRow(
-      column(
-        3,
-        selectInput(ns("irt_model"),
-          "IRT model to use",
-          choices = c(
-            "Module's example 2PL" = "example"
-          )
-        )
-      )
-    ),
-    fluidRow(
-      column(
-        3,
-        sliderInput(
-          ns("true_theta"),
-          # math mode is delimited with \( and \)
-          # in R you have to escape \ with another \, hence the \\
-          # in order to render the math, you have to use some math typesetting library,
-          # e.g., mathjax or, preferably, katex
-          # see preview_mod() definition for more detail
-          "Respondent's true ability (\\(\\theta\\))",
-          value = 1, min = -4, max = 4, step = .1
-        )
-      ),
-      column(
-        3,
-        sliderInput(
-          ns("min_se"),
-          "Min. SE",
-          value = .35, min = 0, max = 1.5, step = .01
-        )
-      ),
-      column(
-        3,
-        # use less efficient way to obtain nice ticks in the slider
-        # normal way would be to use `sliderInput()` here and
-        # `updateSliderInput()` in the server part
-        uiOutput(ns("item_pos_ui"))
-      ),
-      column(
-        3,
-        checkboxInput(ns("only_ans"),
-          "Show IICs for only administered items",
-          value = FALSE
-        )
-      )
-    ),
-    plotlyOutput(ns("merged"), height = "550px"),
-
-    # sample R code -----------------------------------------------------------
-
-    h4("Selected R code"),
-    pre(includeText(system.file("sc/cat.R", package = "SIAmodules")), class = "mb-4 language-r"),
-
-    # references --------------------------------------------------------
-
-    h4("References"),
-    p(
-      "\u0160t\u011bp\u00e1nek, L., Martinkov\u00e1, P. (2020). Feasibility of computerized adaptive testing evaluated by Monte-Carlo and post-hoc simulations. In ",
-      tags$i("Proceedings of the 2020 Federated Conference on Computer Science and Information Systems (FedCSIS),"),
-      " pp. 359\u2013367, ",
-      tags$a(
-        "doi:10.15439/2020F197",
-        href = "https://doi.org/10.15439/2020F197",
-        target = "_blank"
-      )
-    ),
-
-    # acknowledgements --------------------------------------------------------
-
-    h4("Acknowledgements"),
-    p(
-      "This ShinyItemAnalysis Module was developed with support by the Czech Science Foundation under Grant Number",
-      a(
-        "21-03658S",
-        href = "https://www.cs.cas.cz/comps/projectTheorFoundComPs.html",
-        target = "_blank",
-        .noWS = "after"
-      ),
-      "."
-    )
-  )
-}
+# list these specified IRT models that comes from the app
+irt_models <- c(
+  "Module's example 2PL" = "example",
+  "SIA-fitted IRT for binary data" = "sia_binary",
+  "SIA-fitted NRM" = "sia_nrm"
+)
