@@ -505,7 +505,7 @@ sm_dif_c_server <- function(id, imports = NULL, ...) {
 
     output$coef_nlr_dif <- renderDT(
       {
-        coef_nlr_dif() %>% mutate(across(where(is.numeric), ~ round(.x, 3)))
+        coef_nlr_dif() |> mutate(across(where(is.numeric), ~ round(.x, 3)))
       },
       options = list(
         dom = "tipr", pageLength = 10, scrollX = TRUE,
@@ -763,7 +763,7 @@ sm_dif_c_server <- function(id, imports = NULL, ...) {
       )
 
       p$elementId <- NULL
-      hide_legend(p) %>% plotly::config(displayModeBar = FALSE)
+      hide_legend(p) |> plotly::config(displayModeBar = FALSE)
     })
 
     # ** DB for plot ####
@@ -1295,8 +1295,8 @@ total_scores_summary_tab_server <- function(id, dif_matching, group) {
           group = factor(group, labels = c("Basic school track", "Selective academic track"))
         )
 
-        d %>%
-          group_by(group) %>%
+        d |>
+          group_by(group) |>
           summarise(
             n = n(),
             min = min(.data$score, na.rm = TRUE),
@@ -1340,7 +1340,7 @@ total_scores_hist_server <- function(id, dif_matching, group, xlab = NULL) {
           group = factor(group, labels = c("Basic school track", "Selective academic track"))
         )
 
-        d %>%
+        d |>
           ggplot(aes(x = .data$score, fill = .data$group, col = .data$group)) +
           geom_histogram(binwidth = 1, position = "dodge2", alpha = 0.75) +
           xlab(xlab) +
@@ -1357,8 +1357,8 @@ total_scores_hist_server <- function(id, dif_matching, group, xlab = NULL) {
       })
 
       output$plot <- renderPlotly({
-        g <- plt() %>%
-          ggplotly() %>%
+        g <- plt() |>
+          ggplotly() |>
           config(displayModeBar = FALSE)
 
         g$x$data[[1]]$text <- paste0(
